\name{emmixDA}
\alias{emmixDA}
\alias{emmixda}
\alias{emmixpred}
\title{Discriminant Analysis (DA) using Mixture Models}
\description{
Discriminant Analysis (DA) for a specified distribution, including functions to estimate the parameters using training data and clustering, 
then predict the clustering of new data set.

}
\usage{
emmixDA(  test, g, distr, ncov, training, 
popPAR=NULL, itmax=500, epsilon=1e-4)

emmixda(  dat, g, distr, ncov, clust, itmax, epsilon)

emmixpred(dat, g, distr, pro, mu, sigma, dof, delta)

}
\arguments{
\item{test, dat}{A data matrix to be classified}
\item{g}{The number of components of the mixture model}
\item{distr}{ A three letter string indicating the type of distribution to be fitted. "mvn" for a multivariate normal, "mvt" for a multivariate t-distribution, "msn" for a multivariate skew normal distribution and "mst" for a multivariate skew t-distribution.
}
\item{ncov}{ A small integer indicating the type of covariance structure. See Details.}
\item{training}{A list with component of \code{data}, the training data (matrix), and \code{cluster}, the label vector.}
\item{popPAR}{A list with components  \code{pro}, a numeric vector of the mixing proportion of each component; \code{mu}, a p by g matrix with each column as its corresponding mean; 
\code{sigma}, a three dimensional p by p by g array with its jth component matrix (p,p,j) as the covariance matrix for jth component of mixture models;
\code{dof}, a vector of degrees of freedom for each component; \code{delta}, a p by g matrix with its columns corresponding to skew parameter vectors.}
\item{itmax}{The maximum number of iterations }
\item{epsilon}{A small number used for stopping rule }
\item{clust}{A vector of true partition labels of the data  }	
\item{pro }{A length of g vector of mixing proportions}
\item{mu }{A numeric g column matrix with each column corresponding to the mean}
\item{sigma }{An array of dimension (p,p,g) with first two dimensions corresponding covariance matrix of each component}
\item{dof }{A vector of degrees of freedom for each component}
\item{delta}{A matrix with its columns as skew parameter vectors}

}
\details{
The covariance structure type, \code{ncov}, may be any one of the following:
\code{ncov}=1 for a common variance, \code{ncov}=2 for a common diagonal variance, \code{ncov}=3 for a general variance, \code{ncov} =4 for a diagonal variance, \code{ncov}=5 for 
sigma(h)*I(p)(diagonal covariance with same identical diagonal element values).
}
\value{
\item{error}{error code, 0 = normal exit; otherwise, run time error}
\item{pro }{A vector of mixing proportions}
\item{mu }{A numeric matrix with each column corresponding to the mean}
\item{sigma }{An array of dimension (p,p,g) with first two dimensions corresponding covariance matrix of each component}
\item{dof }{A vector of degrees of freedom for each component}
\item{delta}{A matrix with each column as skew parameter vector}
\item{loglik}{loglikelihood}
\item{lk}{A vector of loglikelihood for each EM iteration}

\item{tau}{posterior probability}
\item{belonging}{a vector of clustering labels for each data point}
}
\seealso{ \code{\link{error.rate}}}
\examples{

p=2
g=3



#specify the distribution
distr <- "mvn"

#specify mean and covariance matrix for each component

sigma<-array(0,c(2,2,3))
for(h in 2:3) sigma[,,h]<-diag(2)
sigma[,,1]<-cbind( c(1,-0.1),c(-0.1,1))

mu  <- cbind(c(4,-4),c(3.5,4),c( 0, 0))
pro <- c(0.4,0.3,0.3)


#reset the random seed 
set.seed(111) 

#generate the dataset
n=1000

dobj <- rdemmix3(n,p,g,distr,pro,mu,sigma)

data  <- dobj$data
clust <- dobj$cluster

first  <-   1:600
second <- 601:1000
#use the frist part of data as training

training <- list(data = data[first,],cluster=clust[first])
test     <- data[second,]

#and the second part as test
ret <- emmixDA(test,g, distr, ncov=3, training)

# calculate the error rate
error.rate(clust[second],ret$belonging)


# the above can be done in two steps
popPAR <- emmixda(  data[first,], g, distr, ncov=3, 
clust[first], itmax=100, epsilon=1e-3)

ret <-emmixpred(test, g, distr, popPAR$pro, popPAR$mu, 
popPAR$sigma, popPAR$dof, popPAR$delta)

error.rate(clust[second],ret$belonging)


}
